@@ -2,6 +2,7 @@ from typing import Any, Callable, Dict, Optional
 
 import attr
 
+from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
@@ -20,9 +21,13 @@ class EngagementCredentials:
         server_public = self.server_public
 
         dct = {
-            "clientPublic": client_public,
-            "clientSecret": client_secret,
-            "serverPublic": server_public,
+            k: v
+            for k, v in {
+                "clientPublic": client_public,
+                "clientSecret": client_secret,
+                "serverPublic": server_public,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
